@@ -46,10 +46,10 @@
 
 /* -- version --------------------------------------------------------------- */
 #define G_APP_NAME      "Giada"
-#define G_VERSION_STR   "0.14.1"
+#define G_VERSION_STR   "0.14.3"
 #define G_VERSION_MAJOR 0
 #define G_VERSION_MINOR 14
-#define G_VERSION_PATCH 1
+#define G_VERSION_PATCH 3
 
 #define CONF_FILENAME "giada.conf"
 
@@ -72,18 +72,27 @@
 #define G_GUI_HEIGHT			   510
 #define G_GUI_PLUGIN_RATE    0.05  // refresh rate for plugin GUIs
 #define G_GUI_FONT_SIZE_BASE 12
+#define G_GUI_INNER_MARGIN   4
+#define G_GUI_OUTER_MARGIN   8
+#define G_GUI_UNIT           20    // base unit for elements 
+#define G_GUI_CHANNEL_H_1    G_GUI_UNIT
+#define G_GUI_CHANNEL_H_2    G_GUI_UNIT * 2
+#define G_GUI_CHANNEL_H_3    G_GUI_UNIT * 4
+#define G_GUI_CHANNEL_H_4    G_GUI_UNIT * 6
+
 
 #define G_COLOR_RED       fl_rgb_color(28,  32,  80)
 #define G_COLOR_BLUE      fl_rgb_color(113, 31,  31)
 #define G_COLOR_RED_ALERT fl_rgb_color(239, 75,  53)
 
-#define G_COLOR_LIGHT_2 fl_rgb_color(200, 200, 200)
-#define G_COLOR_LIGHT_1 fl_rgb_color(170, 170, 170)
-#define G_COLOR_GREY_4  fl_rgb_color(78,  78,  78)
-#define G_COLOR_GREY_3  fl_rgb_color(54,  54,  54)
-#define G_COLOR_GREY_2  fl_rgb_color(37,  37,  37)
-#define G_COLOR_GREY_1  fl_rgb_color(25,  25,  25)
-#define G_COLOR_BLACK   fl_rgb_color(0,   0,   0)
+#define G_COLOR_LIGHT_2  fl_rgb_color(200, 200, 200)
+#define G_COLOR_LIGHT_1  fl_rgb_color(170, 170, 170)
+#define G_COLOR_GREY_4   fl_rgb_color(78,  78,  78)
+#define G_COLOR_GREY_3   fl_rgb_color(54,  54,  54)
+#define G_COLOR_GREY_2   fl_rgb_color(37,  37,  37)
+#define G_COLOR_GREY_1_5 fl_rgb_color(28,  28,  28)
+#define G_COLOR_GREY_1   fl_rgb_color(25,  25,  25)
+#define G_COLOR_BLACK    fl_rgb_color(0,   0,   0)
 
 
 
@@ -93,11 +102,13 @@
 #define G_MAX_BEATS				  32
 #define G_MAX_BARS				  32
 #define G_MAX_QUANTIZE      8
-#define G_MAX_PATCHNAME_LEN	32
 #define G_MIN_DB_SCALE      60.0f
 #define G_MIN_COLUMN_WIDTH  140
 #define G_MAX_BOOST_DB      20.0f
 #define G_MAX_PITCH         4.0f
+#define G_MAX_GRID_VAL      64
+#define G_MIN_BUF_SIZE      8
+#define G_MAX_BUF_SIZE      4096
 
 
 
@@ -130,26 +141,28 @@
 #endif
 
 #define G_DEFAULT_SOUNDDEV_OUT    0      // FIXME - please override with rtAudio::getDefaultDevice (or similar)
-#define G_DEFAULT_SOUNDDEV_IN    -1			// no recording by default: input disabled
+#define G_DEFAULT_SOUNDDEV_IN    -1      // no recording by default: input disabled
 #define G_DEFAULT_MIDI_SYSTEM     0
 #define G_DEFAULT_MIDI_PORT_IN   -1
 #define G_DEFAULT_MIDI_PORT_OUT  -1
 #define G_DEFAULT_SAMPLERATE      44100
-#define G_DEFAULT_BUFSIZE		      1024
-#define G_DEFAULT_DELAYCOMP		    0
-#define G_DEFAULT_VOL				      1.0f
-#define G_DEFAULT_PITCH			      1.0f
-#define G_DEFAULT_BOOST			      1.0f
-#define G_DEFAULT_OUT_VOL  	      1.0f
-#define G_DEFAULT_IN_VOL  	      1.0f
-#define G_DEFAULT_CHANMODE	      SINGLE_BASIC
-#define G_DEFAULT_BPM				      120.0f
-#define G_DEFAULT_BEATS			      4
-#define G_DEFAULT_BARS			      1
-#define G_DEFAULT_QUANTIZE        0		  // quantizer off
+#define G_DEFAULT_BUFSIZE         1024
+#define G_DEFAULT_DELAYCOMP       0
+#define G_DEFAULT_BIT_DEPTH       32     // float
+#define G_DEFAULT_AUDIO_CHANS     2      // stereo for internal processing
+#define G_DEFAULT_VOL             1.0f
+#define G_DEFAULT_PITCH           1.0f
+#define G_DEFAULT_BOOST           1.0f
+#define G_DEFAULT_OUT_VOL         1.0f
+#define G_DEFAULT_IN_VOL          1.0f
+#define G_DEFAULT_CHANMODE       SINGLE_BASIC
+#define G_DEFAULT_BPM             120.0f
+#define G_DEFAULT_BEATS           4
+#define G_DEFAULT_BARS            1
+#define G_DEFAULT_QUANTIZE        0      // quantizer off
 #define G_DEFAULT_FADEOUT_STEP    0.01f  // micro-fadeout speed
 #define G_DEFAULT_COLUMN_WIDTH    380
-#define G_DEFAULT_PATCH_NAME       "(default patch)"
+#define G_DEFAULT_PATCH_NAME      "(default patch)"
 #define G_DEFAULT_MIDI_INPUT_UI_W 300
 #define G_DEFAULT_MIDI_INPUT_UI_H 350
 
@@ -183,6 +196,13 @@
 
 
 
+/* -- preview modes --------------------------------------------------------- */
+#define G_PREVIEW_NONE   0x00
+#define G_PREVIEW_NORMAL 0x01
+#define G_PREVIEW_LOOP   0x02
+
+
+
 /* -- actions --------------------------------------------------------------- */
 #define G_ACTION_KEYPRESS		0x01 // 0000 0001
 #define G_ACTION_KEYREL			0x02 // 0000 0010
@@ -200,18 +220,15 @@
 
 
 
-/* -- mixerHandler signals -------------------------------------------------- */
-#define SAMPLE_LOADED_OK      0x01
-#define SAMPLE_LEFT_EMPTY     0x02
-#define SAMPLE_NOT_VALID      0x04
-#define SAMPLE_MULTICHANNEL   0x08
-#define SAMPLE_WRONG_BIT      0x10
-#define SAMPLE_WRONG_ENDIAN   0x20
-#define SAMPLE_WRONG_FORMAT   0x40
-#define SAMPLE_READ_ERROR     0x80
-#define SAMPLE_PATH_TOO_LONG  0x100
-
-/** FIXME - add to SAMPLE_ series those for when exporting */
+/* -- responses and return codes -------------------------------------------- */
+#define G_RES_ERR_PROCESSING    -6
+#define G_RES_ERR_WRONG_DATA    -5
+#define G_RES_ERR_NO_DATA       -4
+#define G_RES_ERR_PATH_TOO_LONG -3
+#define G_RES_ERR_IO            -2
+#define G_RES_ERR_MEMORY        -1
+#define G_RES_ERR                0
+#define G_RES_OK                 1
 
 
 
@@ -341,6 +358,7 @@ const int MIDI_CHANS[16] = {
 #define PATCH_KEY_CHANNELS                     "channels"
 #define PATCH_KEY_CHANNEL_TYPE                 "type"
 #define PATCH_KEY_CHANNEL_INDEX                "index"
+#define PATCH_KEY_CHANNEL_SIZE                 "size"
 #define PATCH_KEY_CHANNEL_COLUMN               "column"
 #define PATCH_KEY_CHANNEL_MUTE                 "mute"
 #define PATCH_KEY_CHANNEL_MUTE_S               "mute_s"
