@@ -6,7 +6,7 @@
  *
  * ---------------------------------------------------------------------
  *
- * Copyright (C) 2010-2016 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -26,8 +26,8 @@
  *
  * ------------------------------------------------------------------ */
 
-#ifndef GRAPHICS_H
-#define GRAPHICS_H
+#ifndef G_GRAPHICS_H
+#define G_GRAPHICS_H
 
 extern const char *giada_logo_xpm[];
 
