@@ -6,7 +6,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2016 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -27,6 +27,7 @@
  * -------------------------------------------------------------------------- */
 
 
+#include "../deps/rtaudio-mod/RtAudio.h"
 #include "../utils/log.h"
 #include "../glue/main.h"
 #include "conf.h"
@@ -35,78 +36,108 @@
 #include "kernelAudio.h"
 
 
-extern KernelAudio G_KernelAudio;
-extern Mixer       G_Mixer;
-extern Conf        G_Conf;
-extern bool	       G_audio_status;
-
-
 using std::string;
 using std::vector;
 
 
-KernelAudio::KernelAudio()
+namespace giada {
+namespace m {
+namespace kernelAudio
 {
-	system       = nullptr;
-	numDevs      = 0;
-	inputEnabled = 0;
-	realBufsize  = 0;
-	api          = 0;
+namespace
+{
+RtAudio *rtSystem;
+bool status;
+unsigned numDevs;
+bool inputEnabled;
+unsigned realBufsize; 		// reale bufsize from the soundcard
+int api;
+
+#ifdef __linux__
+
+JackState jackState;
+
+jack_client_t *jackGetHandle()
+{
+	return static_cast<jack_client_t*>(rtSystem->rtapi_->__HACK__getJackClient());
+}
+
+#endif
+};  // {anonymous}
+
+
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+
+
+void init()
+{
+  rtSystem     = nullptr;
+  numDevs      = 0;
+  inputEnabled = 0;
+  realBufsize  = 0;
+  api          = 0;
 }
 
 
 /* -------------------------------------------------------------------------- */
 
 
-
-int KernelAudio::openDevice(int _api, int outDev,	int inDev, int outChan,
-	int inChan, int samplerate, int buffersize)
+bool getStatus()
 {
-	api = _api;
-	gu_log("[KA] using system 0x%x\n", api);
+  return status;
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+int openDevice()
+{
+	api = conf::soundSystem;
+	gu_log("[KA] using rtSystem 0x%x\n", api);
 
 #if defined(__linux__)
 
-	if (api == SYS_API_JACK && hasAPI(RtAudio::UNIX_JACK))
-		system = new RtAudio(RtAudio::UNIX_JACK);
+	if (api == G_SYS_API_JACK && hasAPI(RtAudio::UNIX_JACK))
+		rtSystem = new RtAudio(RtAudio::UNIX_JACK);
 	else
-	if (api == SYS_API_ALSA && hasAPI(RtAudio::LINUX_ALSA))
-		system = new RtAudio(RtAudio::LINUX_ALSA);
+	if (api == G_SYS_API_ALSA && hasAPI(RtAudio::LINUX_ALSA))
+		rtSystem = new RtAudio(RtAudio::LINUX_ALSA);
 	else
-	if (api == SYS_API_PULSE && hasAPI(RtAudio::LINUX_PULSE))
-		system = new RtAudio(RtAudio::LINUX_PULSE);
+	if (api == G_SYS_API_PULSE && hasAPI(RtAudio::LINUX_PULSE))
+		rtSystem = new RtAudio(RtAudio::LINUX_PULSE);
 
 #elif defined(_WIN32)
 
-	if (api == SYS_API_DS && hasAPI(RtAudio::WINDOWS_DS))
-		system = new RtAudio(RtAudio::WINDOWS_DS);
+	if (api == G_SYS_API_DS && hasAPI(RtAudio::WINDOWS_DS))
+		rtSystem = new RtAudio(RtAudio::WINDOWS_DS);
 	else
-	if (api == SYS_API_ASIO && hasAPI(RtAudio::WINDOWS_ASIO))
-		system = new RtAudio(RtAudio::WINDOWS_ASIO);
+	if (api == G_SYS_API_ASIO && hasAPI(RtAudio::WINDOWS_ASIO))
+		rtSystem = new RtAudio(RtAudio::WINDOWS_ASIO);
 	else
-	if (api == SYS_API_WASAPI && hasAPI(RtAudio::WINDOWS_WASAPI))
-		system = new RtAudio(RtAudio::WINDOWS_WASAPI);
+	if (api == G_SYS_API_WASAPI && hasAPI(RtAudio::WINDOWS_WASAPI))
+		rtSystem = new RtAudio(RtAudio::WINDOWS_WASAPI);
 
 #elif defined(__APPLE__)
 
-	if (api == SYS_API_CORE && hasAPI(RtAudio::MACOSX_CORE))
-		system = new RtAudio(RtAudio::MACOSX_CORE);
+	if (api == G_SYS_API_CORE && hasAPI(RtAudio::MACOSX_CORE))
+		rtSystem = new RtAudio(RtAudio::MACOSX_CORE);
 
 #endif
 
-	else {
-		G_audio_status = false;
+	else
 		return 0;
-	}
 
-	gu_log("[KA] Opening devices %d (out), %d (in), f=%d...\n", outDev, inDev, samplerate);
+	gu_log("[KA] Opening devices %d (out), %d (in), f=%d...\n",
+    conf::soundDeviceOut, conf::soundDeviceIn, conf::samplerate);
 
-	numDevs = system->getDeviceCount();
+	numDevs = rtSystem->getDeviceCount();
 
 	if (numDevs < 1) {
 		gu_log("[KA] no devices found with this API\n");
 		closeDevice();
-		G_audio_status = false;
 		return 0;
 	}
 	else {
@@ -118,62 +149,56 @@ int KernelAudio::openDevice(int _api, int outDev,	int inDev, int outChan,
 	RtAudio::StreamParameters outParams;
 	RtAudio::StreamParameters inParams;
 
-	if (outDev == DEFAULT_SOUNDDEV_OUT)
+	if (conf::soundDeviceOut == G_DEFAULT_SOUNDDEV_OUT)
 		outParams.deviceId = getDefaultOut();
 	else
-		outParams.deviceId = outDev;
+		outParams.deviceId = conf::soundDeviceOut;
 
 	outParams.nChannels = 2;
-	outParams.firstChannel = outChan*2; // chan 0=0, 1=2, 2=4, ...
+	outParams.firstChannel = conf::channelsOut * 2; // chan 0=0, 1=2, 2=4, ...
 
 	/* inDevice can be disabled */
 
-	if (inDev != -1) {
-		inParams.deviceId     = inDev;
+	if (conf::soundDeviceIn != -1) {
+		inParams.deviceId     = conf::soundDeviceIn;
 		inParams.nChannels    = 2;
-		inParams.firstChannel = inChan*2;   // chan 0=0, 1=2, 2=4, ...
+		inParams.firstChannel = conf::channelsIn * 2;   // chan 0=0, 1=2, 2=4, ...
 		inputEnabled = true;
 	}
 	else
 		inputEnabled = false;
 
   RtAudio::StreamOptions options;
-  options.streamName = "Giada";
+  options.streamName = G_APP_NAME;
   options.numberOfBuffers = 4;
 
-	realBufsize = buffersize;
+	realBufsize = conf::buffersize;
 
 #if defined(__linux__) || defined(__APPLE__)
-	if (api == SYS_API_JACK) {
-		samplerate = getFreq(outDev, 0);
-		gu_log("[KA] JACK in use, freq = %d\n", samplerate);
-		G_Conf.samplerate = samplerate;
+
+	if (api == G_SYS_API_JACK) {
+		conf::samplerate = getFreq(conf::soundDeviceOut, 0);
+		gu_log("[KA] JACK in use, freq = %d\n", conf::samplerate);
 	}
+
 #endif
 
 	try {
-		system->openStream(
+		rtSystem->openStream(
 			&outParams, 					              // output params
-			inDev != -1 ? &inParams : nullptr,  // input params if inDevice is selected
+			conf::soundDeviceIn != -1 ? &inParams : nullptr,  // input params if inDevice is selected
 			RTAUDIO_FLOAT32,			              // audio format
-			samplerate, 					              // sample rate
+			conf::samplerate, 					        // sample rate
 			&realBufsize, 				              // buffer size in byte
-			&G_Mixer.masterPlay,                // audio callback
+			&mixer::masterPlay,                 // audio callback
 			nullptr,									          // user data (unused)
 			&options);
-		G_audio_status = true;
-
-#if defined(__linux__)
-		if (api == SYS_API_JACK)
-			jackSetSyncCb();
-#endif
-
+    status = true;
 		return 1;
 	}
 	catch (RtAudioError &e) {
-		gu_log("[KA] system init error: %s\n", e.getMessage().c_str());
+		gu_log("[KA] rtSystem init error: %s\n", e.getMessage().c_str());
 		closeDevice();
-		G_audio_status = false;
 		return 0;
 	}
 }
@@ -182,11 +207,11 @@ int KernelAudio::openDevice(int _api, int outDev,	int inDev, int outChan,
 /* -------------------------------------------------------------------------- */
 
 
-int KernelAudio::startStream()
+int startStream()
 {
 	try {
-		system->startStream();
-		gu_log("[KA] latency = %lu\n", system->getStreamLatency());
+		rtSystem->startStream();
+		gu_log("[KA] latency = %lu\n", rtSystem->getStreamLatency());
 		return 1;
 	}
 	catch (RtAudioError &e) {
@@ -199,10 +224,10 @@ int KernelAudio::startStream()
 /* -------------------------------------------------------------------------- */
 
 
-int KernelAudio::stopStream()
+int stopStream()
 {
 	try {
-		system->stopStream();
+		rtSystem->stopStream();
 		return 1;
 	}
 	catch (RtAudioError &e) {
@@ -215,10 +240,10 @@ int KernelAudio::stopStream()
 /* -------------------------------------------------------------------------- */
 
 
-string KernelAudio::getDeviceName(unsigned dev)
+string getDeviceName(unsigned dev)
 {
 	try {
-		return ((RtAudio::DeviceInfo) system->getDeviceInfo(dev)).name;
+		return static_cast<RtAudio::DeviceInfo>(rtSystem->getDeviceInfo(dev)).name;
 	}
 	catch (RtAudioError &e) {
 		gu_log("[KA] invalid device ID = %d\n", dev);
@@ -230,17 +255,17 @@ string KernelAudio::getDeviceName(unsigned dev)
 /* -------------------------------------------------------------------------- */
 
 
-int KernelAudio::closeDevice()
+int closeDevice()
 {
-	if (system->isStreamOpen()) {
+	if (rtSystem->isStreamOpen()) {
 #if defined(__linux__) || defined(__APPLE__)
-		system->abortStream(); // stopStream seems to lock the thread
+		rtSystem->abortStream(); // stopStream seems to lock the thread
 #elif defined(_WIN32)
-		system->stopStream();	 // on Windows it's the opposite
+		rtSystem->stopStream();	 // on Windows it's the opposite
 #endif
-		system->closeStream();
-		delete system;
-		system = nullptr;
+		rtSystem->closeStream();
+		delete rtSystem;
+		rtSystem = nullptr;
 	}
 	return 1;
 }
@@ -249,12 +274,12 @@ int KernelAudio::closeDevice()
 /* -------------------------------------------------------------------------- */
 
 
-unsigned KernelAudio::getMaxInChans(int dev)
+unsigned getMaxInChans(int dev)
 {
 	if (dev == -1) return 0;
 
 	try {
-		return ((RtAudio::DeviceInfo) system->getDeviceInfo(dev)).inputChannels;
+		return static_cast<RtAudio::DeviceInfo>(rtSystem->getDeviceInfo(dev)).inputChannels;
 	}
 	catch (RtAudioError &e) {
 		gu_log("[KA] Unable to get input channels\n");
@@ -266,10 +291,10 @@ unsigned KernelAudio::getMaxInChans(int dev)
 /* -------------------------------------------------------------------------- */
 
 
-unsigned KernelAudio::getMaxOutChans(unsigned dev)
+unsigned getMaxOutChans(unsigned dev)
 {
 	try {
-		return ((RtAudio::DeviceInfo) system->getDeviceInfo(dev)).outputChannels;
+		return static_cast<RtAudio::DeviceInfo>(rtSystem->getDeviceInfo(dev)).outputChannels;
 	}
 	catch (RtAudioError &e) {
 		gu_log("[KA] Unable to get output channels\n");
@@ -281,10 +306,10 @@ unsigned KernelAudio::getMaxOutChans(unsigned dev)
 /* -------------------------------------------------------------------------- */
 
 
-bool KernelAudio::isProbed(unsigned dev)
+bool isProbed(unsigned dev)
 {
 	try {
-		return ((RtAudio::DeviceInfo) system->getDeviceInfo(dev)).probed;
+		return static_cast<RtAudio::DeviceInfo>(rtSystem->getDeviceInfo(dev)).probed;
 	}
 	catch (RtAudioError &e) {
 		return 0;
@@ -295,10 +320,10 @@ bool KernelAudio::isProbed(unsigned dev)
 /* -------------------------------------------------------------------------- */
 
 
-unsigned KernelAudio::getDuplexChans(unsigned dev)
+unsigned getDuplexChans(unsigned dev)
 {
 	try {
-		return ((RtAudio::DeviceInfo) system->getDeviceInfo(dev)).duplexChannels;
+		return static_cast<RtAudio::DeviceInfo>(rtSystem->getDeviceInfo(dev)).duplexChannels;
 	}
 	catch (RtAudioError &e) {
 		return 0;
@@ -309,10 +334,10 @@ unsigned KernelAudio::getDuplexChans(unsigned dev)
 /* -------------------------------------------------------------------------- */
 
 
-bool KernelAudio::isDefaultIn(unsigned dev)
+bool isDefaultIn(unsigned dev)
 {
 	try {
-		return ((RtAudio::DeviceInfo) system->getDeviceInfo(dev)).isDefaultInput;
+		return static_cast<RtAudio::DeviceInfo>(rtSystem->getDeviceInfo(dev)).isDefaultInput;
 	}
 	catch (RtAudioError &e) {
 		return 0;
@@ -323,10 +348,10 @@ bool KernelAudio::isDefaultIn(unsigned dev)
 /* -------------------------------------------------------------------------- */
 
 
-bool KernelAudio::isDefaultOut(unsigned dev)
+bool isDefaultOut(unsigned dev)
 {
 	try {
-		return ((RtAudio::DeviceInfo) system->getDeviceInfo(dev)).isDefaultOutput;
+		return static_cast<RtAudio::DeviceInfo>(rtSystem->getDeviceInfo(dev)).isDefaultOutput;
 	}
 	catch (RtAudioError &e) {
 		return 0;
@@ -337,10 +362,10 @@ bool KernelAudio::isDefaultOut(unsigned dev)
 /* -------------------------------------------------------------------------- */
 
 
-int KernelAudio::getTotalFreqs(unsigned dev)
+int getTotalFreqs(unsigned dev)
 {
 	try {
-		return ((RtAudio::DeviceInfo) system->getDeviceInfo(dev)).sampleRates.size();
+		return static_cast<RtAudio::DeviceInfo>(rtSystem->getDeviceInfo(dev)).sampleRates.size();
 	}
 	catch (RtAudioError &e) {
 		return 0;
@@ -351,10 +376,10 @@ int KernelAudio::getTotalFreqs(unsigned dev)
 /* -------------------------------------------------------------------------- */
 
 
-int	KernelAudio::getFreq(unsigned dev, int i)
+int	getFreq(unsigned dev, int i)
 {
 	try {
-		return ((RtAudio::DeviceInfo) system->getDeviceInfo(dev)).sampleRates.at(i);
+		return static_cast<RtAudio::DeviceInfo>(rtSystem->getDeviceInfo(dev)).sampleRates.at(i);
 	}
 	catch (RtAudioError &e) {
 		return 0;
@@ -365,21 +390,48 @@ int	KernelAudio::getFreq(unsigned dev, int i)
 /* -------------------------------------------------------------------------- */
 
 
-int KernelAudio::getDefaultIn()
+unsigned getRealBufSize()
 {
-	return system->getDefaultInputDevice();
-}
-
-int KernelAudio::getDefaultOut()
-{
-	return system->getDefaultOutputDevice();
+  return realBufsize;
 }
 
 
 /* -------------------------------------------------------------------------- */
 
 
-int	KernelAudio::getDeviceByName(const char *name)
+bool isInputEnabled()
+{
+  return inputEnabled;
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+unsigned countDevices()
+{
+  return numDevs;
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+int getDefaultIn()
+{
+	return rtSystem->getDefaultInputDevice();
+}
+
+int getDefaultOut()
+{
+	return rtSystem->getDefaultOutputDevice();
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+int	getDeviceByName(const char *name)
 {
 	for (unsigned i=0; i<numDevs; i++)
 		if (name == getDeviceName(i))
@@ -391,7 +443,7 @@ int	KernelAudio::getDeviceByName(const char *name)
 /* -------------------------------------------------------------------------- */
 
 
-bool KernelAudio::hasAPI(int API)
+bool hasAPI(int API)
 {
 	vector<RtAudio::Api> APIs;
 	RtAudio::getCompiledApi(APIs);
@@ -405,97 +457,73 @@ bool KernelAudio::hasAPI(int API)
 /* -------------------------------------------------------------------------- */
 
 
-string KernelAudio::getRtAudioVersion()
-{
-	return RtAudio::getVersion();
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
 #ifdef __linux__
 
-int KernelAudio::jackSyncCb(jack_transport_state_t state, jack_position_t *pos,
-	void *arg)
+
+const JackState &jackTransportQuery()
 {
-	return G_KernelAudio.__jackSyncCb(state, pos, arg);
+	if (api != G_SYS_API_JACK)
+    return jackState;
+  jack_position_t position;
+	jack_transport_state_t ts = jack_transport_query(jackGetHandle(), &position);
+  jackState.running = ts != JackTransportStopped;
+  jackState.bpm     = position.beats_per_minute;
+  jackState.frame   = position.frame;
+  return jackState;
 }
 
 
 /* -------------------------------------------------------------------------- */
 
 
-jack_client_t *KernelAudio::jackGetHandle()
+void jackStart()
 {
-	return (jack_client_t*) system->rtapi_->__HACK__getJackClient();
+	if (api == G_SYS_API_JACK)
+		jack_transport_start(jackGetHandle());
 }
 
 
 /* -------------------------------------------------------------------------- */
 
 
-void KernelAudio::jackStart()
+void jackSetPosition(uint32_t frame)
 {
-	if (api == SYS_API_JACK) {
-		jack_client_t *client = jackGetHandle();
-		jack_transport_start(client);
-	}
+	if (api != G_SYS_API_JACK)
+    return;
+  jack_position_t position;
+  jack_transport_query(jackGetHandle(), &position);
+  position.frame = frame;
+  jack_transport_reposition(jackGetHandle(), &position);
 }
 
 
 /* -------------------------------------------------------------------------- */
 
 
-void KernelAudio::jackStop()
+void jackSetBpm(double bpm)
 {
-	if (api == SYS_API_JACK) {
-		jack_client_t *client = jackGetHandle();
-		jack_transport_stop(client);
-	}
+  if (api != G_SYS_API_JACK)
+    return;
+  jack_position_t position;
+  jack_transport_query(jackGetHandle(), &position);
+  position.valid = jack_position_bits_t::JackPositionBBT;
+  position.bar  = 0;  // no such info from Giada
+  position.beat = 0;  // no such info from Giada
+  position.tick = 0;  // no such info from Giada
+  position.beats_per_minute = bpm;
+  jack_transport_reposition(jackGetHandle(), &position);
 }
 
 
 /* -------------------------------------------------------------------------- */
 
 
-void KernelAudio::jackSetSyncCb()
+void jackStop()
 {
-	jack_client_t *client = jackGetHandle();
-	jack_set_sync_callback(client, jackSyncCb, nullptr);
-	//jack_set_sync_timeout(client, 8);
+	if (api == G_SYS_API_JACK)
+		jack_transport_stop(jackGetHandle());
 }
 
+#endif  // #ifdef __linux__
 
-/* -------------------------------------------------------------------------- */
-
-
-int KernelAudio::__jackSyncCb(jack_transport_state_t state, jack_position_t *pos,
-		void *arg)
-{
-	switch (state) {
-		case JackTransportStopped:
-			gu_log("[KA] Jack transport stopped, frame=%d\n", pos->frame);
-			glue_stopSeq(false);  // false = not from GUI
-			if (pos->frame == 0)
-				glue_rewindSeq();
-			break;
-
-		case JackTransportRolling:
-			gu_log("[KA] Jack transport rolling\n");
-			break;
-
-		case JackTransportStarting:
-			gu_log("[KA] Jack transport starting, frame=%d\n", pos->frame);
-			glue_startSeq(false);  // false = not from GUI
-			if (pos->frame == 0)
-				glue_rewindSeq();
-			break;
-
-		default:
-			gu_log("[KA] Jack transport [unknown]\n");
-	}
-	return 1;
-}
-
-#endif
+}}}; // giada::m::kernelAudio
