@@ -31,7 +31,6 @@
 #include "../utils/log.h"
 #include "../glue/main.h"
 #include "../glue/channel.h"
-#include "mixerHandler.h"
 #include "kernelMidi.h"
 #include "mixer.h"
 #include "const.h"
@@ -49,6 +48,8 @@
 #include "sampleChannel.h"
 #include "midiChannel.h"
 #include "wave.h"
+#include "waveManager.h"
+#include "mixerHandler.h"
 
 
 using std::vector;
@@ -68,7 +69,7 @@ int readPatchPlugins(vector<patch::plugin_t> *list, int type)
 	int ret = 1;
 	for (unsigned i=0; i<list->size(); i++) {
 		patch::plugin_t *ppl = &list->at(i);
-    // TODO use glue_addPlugin()
+		// TODO use glue_addPlugin()
 		Plugin *plugin = pluginHost::addPlugin(ppl->path.c_str(), type,
 				&mixer::mutex_plugins, nullptr);
 		if (plugin != nullptr) {
@@ -114,15 +115,15 @@ int getNewChanIndex()
 /* -------------------------------------------------------------------------- */
 
 
-bool uniqueSampleName(SampleChannel *ch, const string &name)
+bool uniqueSampleName(SampleChannel* ch, const string& name)
 {
 	for (unsigned i=0; i<mixer::channels.size(); i++) {
 		if (ch == mixer::channels.at(i))  // skip itself
 			continue;
 		if (mixer::channels.at(i)->type != CHANNEL_SAMPLE)
 			continue;
-		SampleChannel *other = (SampleChannel*) mixer::channels.at(i);
-		if (other->wave != nullptr && name == other->wave->name)
+		SampleChannel* other = (SampleChannel*) mixer::channels.at(i);
+		if (other->wave != nullptr && name == other->wave->getName())
 			return false;
 	}
 	return true;
@@ -132,9 +133,9 @@ bool uniqueSampleName(SampleChannel *ch, const string &name)
 /* -------------------------------------------------------------------------- */
 
 
-Channel *addChannel(int type)
+Channel* addChannel(int type)
 {
-  Channel *ch;
+	Channel* ch;
 	int bufferSize = kernelAudio::getRealBufSize() * 2;
 
 	if (type == CHANNEL_SAMPLE)
@@ -142,9 +143,14 @@ Channel *addChannel(int type)
 	else
 		ch = new MidiChannel(bufferSize);
 
+	if (!ch->allocBuffers()) {
+		delete ch;
+		return nullptr;
+	}
+
 	while (true) {
 		if (pthread_mutex_trylock(&mixer::mutex_chans) != 0)
-      continue;
+			continue;
 		mixer::channels.push_back(ch);
 		pthread_mutex_unlock(&mixer::mutex_chans);
 		break;
@@ -152,7 +158,7 @@ Channel *addChannel(int type)
 
 	ch->index = getNewChanIndex();
 	gu_log("[addChannel] channel index=%d added, type=%d, total=%d\n",
-    ch->index, ch->type, mixer::channels.size());
+		ch->index, ch->type, mixer::channels.size());
 	return ch;
 }
 
@@ -160,7 +166,7 @@ Channel *addChannel(int type)
 /* -------------------------------------------------------------------------- */
 
 
-int deleteChannel(Channel *ch)
+int deleteChannel(Channel* ch)
 {
 	int index = -1;
 	for (unsigned i=0; i<mixer::channels.size(); i++) {
@@ -176,7 +182,7 @@ int deleteChannel(Channel *ch)
 
 	while (true) {
 		if (pthread_mutex_trylock(&mixer::mutex_chans) != 0)
-      continue;
+			continue;
 		mixer::channels.erase(mixer::channels.begin() + index);
 		delete ch;
 		pthread_mutex_unlock(&mixer::mutex_chans);
@@ -188,7 +194,7 @@ int deleteChannel(Channel *ch)
 /* -------------------------------------------------------------------------- */
 
 
-Channel *getChannelByIndex(int index)
+Channel* getChannelByIndex(int index)
 {
 	for (unsigned i=0; i<mixer::channels.size(); i++)
 		if (mixer::channels.at(i)->index == index)
@@ -204,12 +210,12 @@ Channel *getChannelByIndex(int index)
 bool hasLogicalSamples()
 {
 	for (unsigned i=0; i<mixer::channels.size(); i++) {
-    if (mixer::channels.at(i)->type != CHANNEL_SAMPLE)
-      continue;
-    SampleChannel *ch = static_cast<SampleChannel*>(mixer::channels.at(i));
-    if (ch->wave && ch->wave->isLogical)
-      return true;
-  }
+		if (mixer::channels.at(i)->type != CHANNEL_SAMPLE)
+			continue;
+		SampleChannel *ch = static_cast<SampleChannel*>(mixer::channels.at(i));
+		if (ch->wave && ch->wave->isLogical())
+			return true;
+	}
 	return false;
 }
 
@@ -220,13 +226,13 @@ bool hasLogicalSamples()
 bool hasEditedSamples()
 {
 	for (unsigned i=0; i<mixer::channels.size(); i++)
-  {
+	{
 		if (mixer::channels.at(i)->type != CHANNEL_SAMPLE)
-      continue;
-    SampleChannel *ch = static_cast<SampleChannel*>(mixer::channels.at(i));
-    if (ch->wave && ch->wave->isEdited)
-      return true;
-  }
+			continue;
+		SampleChannel *ch = static_cast<SampleChannel*>(mixer::channels.at(i));
+		if (ch->wave && ch->wave->isEdited())
+			return true;
+	}
 	return false;
 }
 
@@ -236,7 +242,7 @@ bool hasEditedSamples()
 
 void stopSequencer()
 {
-  clock::stop();
+	clock::stop();
 	for (unsigned i=0; i<mixer::channels.size(); i++)
 		mixer::channels.at(i)->stopBySeq(conf::chansStopOnSeqHalt);
 }
@@ -245,7 +251,7 @@ void stopSequencer()
 /* -------------------------------------------------------------------------- */
 
 
-bool uniqueSolo(Channel *ch)
+bool uniqueSolo(Channel* ch)
 {
 	int solos = 0;
 	for (unsigned i=0; i<mixer::channels.size(); i++) {
@@ -264,13 +270,13 @@ void readPatch()
 {
 	mixer::ready = false;
 
-	mixer::outVol     = patch::masterVolOut;
-	mixer::inVol      = patch::masterVolIn;
+	mixer::outVol = patch::masterVolOut;
+	mixer::inVol = patch::masterVolIn;
 	clock::setBpm(patch::bpm);
 	clock::setBars(patch::bars);
 	clock::setBeats(patch::beats);
 	clock::setQuantize(patch::quantize);
-	mixer::metronome  = patch::metronome;
+	mixer::metronome = patch::metronome;
 
 #ifdef WITH_VST
 
@@ -306,27 +312,31 @@ bool startInputRec()
 {
 	int channelsReady = 0;
 
-	for (unsigned i=0; i<mixer::channels.size(); i++) {
+	for (Channel* channel : mixer::channels) {
 
-		if (!mixer::channels.at(i)->canInputRec())
+		if (!channel->canInputRec())
 			continue;
 
-		SampleChannel *ch = (SampleChannel*) mixer::channels.at(i);
+		SampleChannel* ch = static_cast<SampleChannel*>(channel);
 
 		/* Allocate empty sample for the current channel. */
 
-		if (!ch->allocEmpty(clock::getTotalFrames(), conf::samplerate, patch::lastTakeId))
-		{
+		Wave* wave = nullptr;
+		int result = waveManager::createEmpty(clock::getTotalFrames(), 
+			conf::samplerate, string("TAKE-" + gu_toString(patch::lastTakeId)), &wave); 
+		if (result != G_RES_OK) {
 			gu_log("[startInputRec] unable to allocate new Wave in chan %d!\n",
 				ch->index);
 			continue;
 		}
 
-		/* Increase lastTakeId until the sample name TAKE-[n] is unique */
+		ch->pushWave(wave, false);  // false: don't generate name, we provide it
 
-		while (!uniqueSampleName(ch, ch->wave->name)) {
+		/* Increase lastTakeId until the sample name TAKE-[n] is unique. */
+
+		while (!uniqueSampleName(ch, ch->wave->getName())) {
 			patch::lastTakeId++;
-			ch->wave->name = "TAKE-" + gu_itoa(patch::lastTakeId);
+			ch->wave->setName("TAKE-" + gu_toString(patch::lastTakeId));
 		}
 
 		gu_log("[startInputRec] start input recs using chan %d with size %d "
@@ -363,12 +373,12 @@ void stopInputRec()
 
 bool hasArmedSampleChannels()
 {
-  for (unsigned i=0; i<mixer::channels.size(); i++) {
-    Channel *ch = mixer::channels.at(i);
-    if (ch->type == CHANNEL_SAMPLE && ch->armed)
-      return true;
-  }
-  return false;
+	for (unsigned i=0; i<mixer::channels.size(); i++) {
+		Channel *ch = mixer::channels.at(i);
+		if (ch->type == CHANNEL_SAMPLE && ch->armed)
+			return true;
+	}
+	return false;
 }
 
 
