@@ -27,10 +27,10 @@
 
 #include <cmath>
 #include <cstring>
+#include <cassert>
 #include "../utils/log.h"
 #include "../utils/fs.h"
 #include "../utils/string.h"
-#include "sampleChannel.h"
 #include "patch.h"
 #include "const.h"
 #include "conf.h"
@@ -39,9 +39,11 @@
 #include "wave.h"
 #include "pluginHost.h"
 #include "waveFx.h"
+#include "waveManager.h"
 #include "mixerHandler.h"
 #include "kernelMidi.h"
 #include "kernelAudio.h"
+#include "sampleChannel.h"
 
 
 using std::string;
@@ -50,13 +52,17 @@ using namespace giada::m;
 
 SampleChannel::SampleChannel(int bufferSize, bool inputMonitor)
 	: Channel          (CHANNEL_SAMPLE, STATUS_EMPTY, bufferSize),
+		rsmp_state       (nullptr),
+		pChan            (nullptr),
+		vChanPreview     (nullptr),
 		frameRewind      (-1),
-		boost            (G_DEFAULT_BOOST),
-		pitch            (G_DEFAULT_PITCH),
-		wave             (nullptr),
-		tracker          (0),
 		begin            (0),
 		end              (0),
+		boost            (G_DEFAULT_BOOST),
+		pitch            (G_DEFAULT_PITCH),
+		trackerPreview   (0),
+		wave             (nullptr),
+		tracker          (0),
 		mode             (G_DEFAULT_CHANMODE),
 		qWait	           (false),
 		fadeinOn         (false),
@@ -65,12 +71,10 @@ SampleChannel::SampleChannel(int bufferSize, bool inputMonitor)
 		fadeoutVol       (1.0f),
 		fadeoutTracker   (0),
 		fadeoutStep      (G_DEFAULT_FADEOUT_STEP),
-    inputMonitor     (inputMonitor),
-	  midiInReadActions(0x0),
-	  midiInPitch      (0x0)
+		inputMonitor     (inputMonitor),
+		midiInReadActions(0x0),
+		midiInPitch      (0x0)
 {
-	rsmp_state = src_new(SRC_LINEAR, 2, nullptr);
-	pChan = (float *) malloc(kernelAudio::getRealBufSize() * 2 * sizeof(float));
 }
 
 
@@ -79,20 +83,54 @@ SampleChannel::SampleChannel(int bufferSize, bool inputMonitor)
 
 SampleChannel::~SampleChannel()
 {
-	if (wave)
+	if (wave != nullptr)
 		delete wave;
-	src_delete(rsmp_state);
-	free(pChan);
+	if (rsmp_state != nullptr)
+		src_delete(rsmp_state);
+	if (pChan != nullptr)
+		delete[] pChan;	
+	if (vChanPreview != nullptr)
+		delete[] vChanPreview;
 }
 
 
 /* -------------------------------------------------------------------------- */
 
 
-void SampleChannel::copy(const Channel *_src, pthread_mutex_t *pluginMutex)
+bool SampleChannel::allocBuffers()
+{
+	if (!Channel::allocBuffers())
+		return false;
+
+	rsmp_state = src_new(SRC_LINEAR, 2, nullptr);
+	if (rsmp_state == nullptr) {
+		gu_log("[SampleChannel::allocBuffers] unable to alloc memory for SRC_STATE!\n");
+		return false;
+	}
+
+	pChan = new (std::nothrow) float[bufferSize];
+	if (pChan == nullptr) {
+		gu_log("[SampleChannel::allocBuffers] unable to alloc memory for pChan!\n");
+		return false;
+	}
+
+	vChanPreview = new (std::nothrow) float[bufferSize];
+	if (vChanPreview == nullptr) {
+		gu_log("[SampleChannel::allocBuffers] unable to alloc memory for vChanPreview!\n");
+		return false;
+	}
+
+	return true;
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void SampleChannel::copy(const Channel* _src, pthread_mutex_t* pluginMutex)
 {
 	Channel::copy(_src, pluginMutex);
-	SampleChannel *src = (SampleChannel *) _src;
+	const SampleChannel* src = static_cast<const SampleChannel*>(_src);
 	tracker         = src->tracker;
 	begin           = src->begin;
 	end             = src->end;
@@ -109,11 +147,8 @@ void SampleChannel::copy(const Channel *_src, pthread_mutex_t *pluginMutex)
 	fadeoutEnd      = src->fadeoutEnd;
 	setPitch(src->pitch);
 
-	if (src->wave) {
-		Wave *w = new Wave(*src->wave); // invoke Wave's copy constructor
-		pushWave(w);
-		generateUniqueSampleName();
-	}
+	if (src->wave)
+		pushWave(new Wave(*src->wave)); // invoke Wave's copy constructor
 }
 
 
@@ -122,10 +157,10 @@ void SampleChannel::copy(const Channel *_src, pthread_mutex_t *pluginMutex)
 
 void SampleChannel::generateUniqueSampleName()
 {
-	string oldName = wave->name;
-	int k = 1; // Start from k = 1, zero is too nerdy
-	while (!mh::uniqueSampleName(this, wave->name)) {
-		wave->updateName((oldName + "-" + gu_itoa(k)).c_str());
+	string oldName = wave->getName();
+	int k = 0;
+	while (!mh::uniqueSampleName(this, wave->getName())) {
+		wave->setName(oldName + "-" + gu_toString(k));
 		k++;
 	}
 }
@@ -139,8 +174,8 @@ void SampleChannel::clear()
 	/** TODO - these memsets can be done only if status PLAY (if below),
 	 * but it would require extra clearPChan calls when samples stop */
 
-		std::memset(vChan, 0, sizeof(float) * bufferSize);
-		std::memset(pChan, 0, sizeof(float) * bufferSize);
+	std::memset(vChan, 0, sizeof(float) * bufferSize);
+	std::memset(pChan, 0, sizeof(float) * bufferSize);
 
 	if (status & (STATUS_PLAY | STATUS_ENDING)) {
 		tracker = fillChan(vChan, tracker, 0);
@@ -226,46 +261,96 @@ void SampleChannel::onBar(int frame)
 /* -------------------------------------------------------------------------- */
 
 
-int SampleChannel::save(const char *path)
+int SampleChannel::save(const char* path)
 {
-	return wave->writeData(path);
+	return waveManager::save(wave, path);
 }
 
 
 /* -------------------------------------------------------------------------- */
 
 
-void SampleChannel::setBegin(int v)
+void SampleChannel::setBegin(int f)
 {
-	if (v < 0)
+	/* TODO - Opaque channel's count - everything in SampleChannel should be
+	frame-based, not sample-based. I.e. Remove * wave->getChannels() stuff. */
+
+	if (f < 0)
 		begin = 0;
 	else
-	if (v > wave->size)
-		begin = wave->size - 2;
+	if (f > wave->getSize())
+		begin = wave->getSize() * wave->getChannels();
 	else
-	if (v >= end)
-		begin = end - 2;
+	if (f >= end)
+		begin = end - wave->getChannels();
 	else
-		begin = v;
+		begin = f * wave->getChannels();
+
 	tracker = begin;
+	trackerPreview = begin;
 }
 
 
 /* -------------------------------------------------------------------------- */
 
 
-void SampleChannel::setEnd(int v)
+void SampleChannel::setEnd(int f)
 {
-	if (v < 0)
-		end = begin + 2;
+	/* TODO - Opaque channel's count - everything in SampleChannel should be
+	frame-based, not sample-based. I.e. Remove * wave->getChannels() stuff. */
+	
+	if (f < 0)
+		end = begin + wave->getChannels();
 	else
-	if (v > wave->size)
-		end = wave->size;
+	if (f >= wave->getSize())
+		end = (wave->getSize() - 1) * wave->getChannels();
 	else
-	if (v <= begin)
-		end = begin + 2;
+	if (f * wave->getChannels() <= begin)
+		end = begin + wave->getChannels();
 	else
-		end = v;
+		end = f * wave->getChannels();
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+int SampleChannel::getBegin()
+{
+	/* TODO - Opaque channel's count - everything in SampleChannel should be
+	frame-based, not sample-based. I.e. Remove / wave->getChannels() stuff. */
+	
+	return begin / wave->getChannels();
+}
+
+
+int SampleChannel::getEnd()
+{
+	/* TODO - Opaque channel's count - everything in SampleChannel should be
+	frame-based, not sample-based. I.e. Remove / wave->getChannels() stuff. */
+
+	return end / wave->getChannels();
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void SampleChannel::setTrackerPreview(int f)
+{
+	/* TODO - Opaque channel's count - everything in SampleChannel should be
+	frame-based, not sample-based. I.e. Remove * wave->getChannels() stuff. */
+	
+	trackerPreview = f * wave->getChannels();
+}
+
+
+int SampleChannel::getTrackerPreview() const
+{
+	/* TODO - Opaque channel's count - everything in SampleChannel should be
+	frame-based, not sample-based. I.e. Remove / wave->getChannels() stuff. */
+
+	return trackerPreview / wave->getChannels();
 }
 
 
@@ -314,7 +399,7 @@ void SampleChannel::rewind()
 /* -------------------------------------------------------------------------- */
 
 
-void SampleChannel::parseAction(recorder::action *a, int localFrame,
+void SampleChannel::parseAction(recorder::action* a, int localFrame,
 		int globalFrame, int quantize, bool mixerIsRunning)
 {
 	if (readActions == false)
@@ -548,8 +633,11 @@ void SampleChannel::quantize(int index, int localFrame)
 
 int SampleChannel::getPosition()
 {
+	/* TODO - Opaque channel's count - everything in SampleChannel should be
+	frame-based, not sample-based. I.e. Remove / wave->getChannels() stuff. */
+
 	if (status & ~(STATUS_EMPTY | STATUS_MISSING | STATUS_OFF)) // if is not (...)
-		return tracker - begin;
+		return (tracker - begin) / wave->getChannels();
 	else
 		return -1;
 }
@@ -673,6 +761,15 @@ void SampleChannel::setReadActions(bool v, bool recsStopOnChanHalt)
 /* -------------------------------------------------------------------------- */
 
 
+void SampleChannel::setOnEndPreviewCb(std::function<void()> f)
+{
+	onPreviewEnd = f;
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
 void SampleChannel::setFadeIn(bool internal)
 {
 	if (internal) mute_i = false;  // remove mute before fading in
@@ -713,20 +810,20 @@ void SampleChannel::setXFade(int frame)
 
 /* -------------------------------------------------------------------------- */
 
+/* On reset, if frame > 0 and in play, fill again pChan to create something like 
+this:
 
-/* on reset, if frame > 0 and in play, fill again pChan to create
- * something like this:
- *
- * |abcdefabcdefab*abcdefabcde|
- * [old data-----]*[new data--]
- *
- * */
+	|abcdefabcdefab*abcdefabcde|
+	[old data-----]*[new data--]
+
+*/
 
 void SampleChannel::reset(int frame)
 {
 	//fadeoutTracker = tracker;   // store old frame number for xfade
 	tracker = begin;
 	mute_i  = false;
+	qWait   = false;  // Was in qWait mode? Reset occured, no more qWait now.
 	if (frame > 0 && status & (STATUS_PLAY | STATUS_ENDING))
 		tracker = fillChan(vChan, tracker, frame);
 }
@@ -738,7 +835,7 @@ void SampleChannel::reset(int frame)
 void SampleChannel::empty()
 {
 	status = STATUS_OFF;
-	if (wave) {
+	if (wave != nullptr) {
 		delete wave;
 		wave = nullptr;
 	}
@@ -755,42 +852,22 @@ void SampleChannel::empty()
 /* -------------------------------------------------------------------------- */
 
 
-void SampleChannel::pushWave(Wave *w)
+void SampleChannel::pushWave(Wave* w, bool generateName)
 {
+	sendMidiLplay();     // FIXME - why here?!?!
 	wave   = w;
 	status = STATUS_OFF;
-	sendMidiLplay();     // FIXME - why here?!?!
 	begin  = 0;
-	end    = wave->size;
+	end    = (wave->getSize() - 1) * wave->getChannels(); // TODO - Opaque channels' count
+	if (generateName)
+		generateUniqueSampleName();
 }
 
 
 /* -------------------------------------------------------------------------- */
 
 
-bool SampleChannel::allocEmpty(int frames, int samplerate, int takeId)
-{
-	Wave *w = new Wave();
-	if (!w->allocEmpty(frames, samplerate))
-		return false;
-
-	w->name     = "TAKE-" + gu_itoa(takeId);
-	w->pathfile = gu_getCurrentPath() + G_SLASH + w->name;
-	wave        = w;
-	status      = STATUS_OFF;
-	begin       = 0;
-	end         = wave->size;
-
-	sendMidiLplay();  // FIXME - why here?!?!
-
-	return true;
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
-void SampleChannel::process(float *outBuffer, float *inBuffer)
+void SampleChannel::process(float* outBuffer, float* inBuffer)
 {
 	/* If armed and inbuffer is not nullptr (i.e. input device available) and
   input monitor is on, copy input buffer to vChan: this enables the input
@@ -815,6 +892,42 @@ void SampleChannel::process(float *outBuffer, float *inBuffer)
 /* -------------------------------------------------------------------------- */
 
 
+void SampleChannel::preview(float* outBuffer)
+{
+	if (previewMode == G_PREVIEW_NONE)
+		return;
+
+	std::memset(vChanPreview, 0, sizeof(float) * bufferSize);
+
+	/* If the tracker exceedes the end point and preview is looped, split the 
+	rendering as in SampleChannel::reset(). */
+
+	if (trackerPreview + bufferSize >= end) {
+		int offset = end - trackerPreview;
+		trackerPreview = fillChan(vChanPreview, trackerPreview, 0, false);
+		trackerPreview = begin;
+		if (previewMode == G_PREVIEW_LOOP)
+			trackerPreview = fillChan(vChanPreview, begin, offset, false);
+		else
+		if (previewMode == G_PREVIEW_NORMAL) {
+			previewMode = G_PREVIEW_NONE;
+			if (onPreviewEnd)
+				onPreviewEnd();
+		}
+	}
+	else
+		trackerPreview = fillChan(vChanPreview, trackerPreview, 0, false);
+
+	for (int j=0; j<bufferSize; j+=2) {
+		outBuffer[j]   += vChanPreview[j]   * volume * calcPanning(0) * boost;
+		outBuffer[j+1] += vChanPreview[j+1] * volume * calcPanning(1) * boost;
+	}
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
 void SampleChannel::kill(int frame)
 {
 	if (wave != nullptr && status != STATUS_OFF) {
@@ -877,55 +990,6 @@ void SampleChannel::stop()
 /* -------------------------------------------------------------------------- */
 
 
-int SampleChannel::load(const char *file, int samplerate, int rsmpQuality)
-{
-	if (strcmp(file, "") == 0 || gu_isDir(file)) {
-		gu_log("[SampleChannel] file not specified\n");
-		return SAMPLE_LEFT_EMPTY;
-	}
-
-	if (strlen(file) > FILENAME_MAX)
-		return SAMPLE_PATH_TOO_LONG;
-
-	Wave *w = new Wave();
-
-	if (!w->open(file)) {
-		gu_log("[SampleChannel] %s: read error\n", file);
-		delete w;
-		return SAMPLE_READ_ERROR;
-	}
-
-	if (w->channels() > 2) {
-		gu_log("[SampleChannel] %s: unsupported multichannel wave\n", file);
-		delete w;
-		return SAMPLE_MULTICHANNEL;
-	}
-
-	if (!w->readData()) {
-		delete w;
-		return SAMPLE_READ_ERROR;
-	}
-
-	if (w->channels() == 1) /** FIXME: error checking  */
-		wfx_monoToStereo(w);
-
-	if (w->rate() != samplerate) {
-		gu_log("[SampleChannel] input rate (%d) != system rate (%d), conversion needed\n",
-				w->rate(), samplerate);
-		w->resample(rsmpQuality, samplerate);
-	}
-
-	pushWave(w);
-	generateUniqueSampleName();
-
-	gu_log("[SampleChannel] %s loaded in channel %d\n", file, index);
-	return SAMPLE_LOADED_OK;
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
 int SampleChannel::readPatch(const string &basePath, int i,
 		pthread_mutex_t *pluginMutex, int samplerate, int rsmpQuality)
 {
@@ -944,17 +1008,20 @@ int SampleChannel::readPatch(const string &basePath, int i,
 	midiInPitch       = pch->midiInPitch;
   inputMonitor      = pch->inputMonitor;
 
-	int res = load((basePath + pch->samplePath).c_str(), samplerate, rsmpQuality);
-	if (res == SAMPLE_LOADED_OK) {
+  Wave *w = nullptr;
+  int res = waveManager::create(basePath + pch->samplePath, &w); 
+
+	if (res == G_RES_OK) {
+		pushWave(w);
 		setBegin(pch->begin);
 		setEnd  (pch->end);
 		setPitch(pch->pitch);
 	}
 	else {
-		if (res == SAMPLE_LEFT_EMPTY)
+		if (res == G_RES_ERR_NO_DATA)
 			status = STATUS_EMPTY;
 		else
-		if (res == SAMPLE_READ_ERROR)
+		if (res == G_RES_ERR_IO)
 			status = STATUS_MISSING;
 		sendMidiLplay();  // FIXME - why sending MIDI lightning if sample status is wrong?
 	}
@@ -1058,9 +1125,9 @@ int SampleChannel::writePatch(int i, bool isProject)
 	patch::channel_t *pch = &patch::channels.at(pchIndex);
 
 	if (wave != nullptr) {
-		pch->samplePath = wave->pathfile;
+		pch->samplePath = wave->getPath();
 		if (isProject)
-			pch->samplePath = gu_basename(wave->pathfile);  // make it portable
+			pch->samplePath = gu_basename(wave->getPath());  // make it portable
 	}
 	else
 		pch->samplePath = "";
@@ -1101,7 +1168,7 @@ int SampleChannel::fillChan(float *dest, int start, int offset, bool rewind)
 		 * end) */
 
 		if (start+bufferSize-offset <= end) {
-			memcpy(dest+offset, wave->data+start, (bufferSize-offset)*sizeof(float));
+			memcpy(dest+offset, wave->getData()+start, (bufferSize-offset)*sizeof(float));
 			position = start+bufferSize-offset;
 			if (rewind)
 				frameRewind = -1;
@@ -1111,7 +1178,7 @@ int SampleChannel::fillChan(float *dest, int start, int offset, bool rewind)
 		 * is smaller than 'dest' */
 
 		else {
-			memcpy(dest+offset, wave->data+start, (end-start)*sizeof(float));
+			memcpy(dest+offset, wave->getData()+start, (end-start)*sizeof(float));
 			position = end;
 			if (rewind)
 				frameRewind = end-start+offset;
@@ -1119,7 +1186,7 @@ int SampleChannel::fillChan(float *dest, int start, int offset, bool rewind)
 	}
 	else {
 
-		rsmp_data.data_in       = wave->data+start;         // source data
+		rsmp_data.data_in       = wave->getData()+start;    // source data
 		rsmp_data.input_frames  = (end-start)/2;            // how many readable bytes
 		rsmp_data.data_out      = dest+offset;              // destination (processed data)
 		rsmp_data.output_frames = (bufferSize-offset)/2;    // how many bytes to process
