@@ -29,6 +29,7 @@
 #define G_SAMPLE_CHANNEL_H
 
 
+#include <functional>
 #include <samplerate.h>
 #include "channel.h"
 
@@ -44,33 +45,46 @@ private:
 	/* rsmp_state, rsmp_data
 	 * structs from libsamplerate */
 
-	SRC_STATE *rsmp_state;
+	SRC_STATE* rsmp_state;
 	SRC_DATA   rsmp_data;
 
 	/* pChan
 	Extra virtual channel for processing resampled data. */
 
-	float *pChan;
+	float* pChan;
+
+	/* pChan
+	Extra virtual channel for audio preview. */
+
+	float* vChanPreview;
 
 	/* frameRewind
 	Exact frame in which a rewind occurs. */
 
 	int frameRewind;
 
+	int   begin;
+	int   end;
 	float boost;
 	float pitch;
+	int   trackerPreview;  // chan position for audio preview
+
+	/* onPreviewEnd
+	A callback fired when audio preview ends. */
+
+	std::function<void()> onPreviewEnd;
 
 	/* fillChan
-	 * copy from wave to *dest and resample data from wave, if necessary.
-	 * Start to fill pChan from byte 'offset'. If rewind=false don't
-	 * rewind internal tracker. Returns new sample position, in frames */
+	Fills 'dest' buffer at point 'offset' with wave data taken from 'start'. If 
+	rewind=false don't rewind internal tracker. Returns new sample position, 
+	in frames. It resamples data if pitch != 1.0f. */
 
-	int fillChan(float *dest, int start, int offset, bool rewind=true);
+	int fillChan(float* dest, int start, int offset, bool rewind=true);
 
 	/* clearChan
 	 * set data to zero from start to bufferSize-1. */
 
-	void clearChan(float *dest, int start);
+	void clearChan(float* dest, int start);
 
 	/* calcFadeoutStep
 	 * how many frames are left before the end of the sample? Is there
@@ -94,9 +108,10 @@ public:
 	SampleChannel(int bufferSize, bool inputMonitor);
 	~SampleChannel();
 
-	void copy(const Channel *src, pthread_mutex_t *pluginMutex) override;
+	void copy(const Channel* src, pthread_mutex_t* pluginMutex) override;
 	void clear() override;
-	void process(float *outBuffer, float *inBuffer) override;
+	void process(float* outBuffer, float* inBuffer) override;
+	void preview(float* outBuffer) override;
 	void start(int frame, bool doQuantize, int quantize, bool mixerIsRunning,
 		bool forceStart, bool isUserGenerated) override;
 	void kill(int frame) override;
@@ -106,17 +121,16 @@ public:
 	void rewind() override;
 	void setMute(bool internal) override;
 	void unsetMute(bool internal) override;
-  int readPatch(const std::string &basePath, int i, pthread_mutex_t *pluginMutex,
+  int readPatch(const std::string& basePath, int i, pthread_mutex_t* pluginMutex,
     int samplerate, int rsmpQuality) override;
 	int writePatch(int i, bool isProject) override;
 	void quantize(int index, int localFrame) override;
 	void onZero(int frame, bool recsStopOnChanHalt) override;
 	void onBar(int frame) override;
-	void parseAction(giada::m::recorder::action *a, int localFrame, int globalFrame,
+	void parseAction(giada::m::recorder::action* a, int localFrame, int globalFrame,
 			int quantize, bool mixerIsRunning) override;
 	bool canInputRec() override;
-
-	int load(const char *file, int samplerate, int rsmpQuality);
+	bool allocBuffers() override;
 
 	void reset(int frame);
 
@@ -124,14 +138,15 @@ public:
 	 * prepare channel for fade, mixer will take care of the process
 	 * during master play. */
 
-	void  setFadeIn  (bool internal);
-	void  setFadeOut (int actionPostFadeout);
-	void  setXFade   (int frame);
+	void setFadeIn(bool internal);
+	void setFadeOut(int actionPostFadeout);
+	void setXFade(int frame);
 
 	/* pushWave
-	 * add a new wave to an existing channel. */
+	Adds a new wave to an existing channel. It also generates a unique name
+	on request. */
 
-	void pushWave(Wave *w);
+	void pushWave(Wave* w, bool generateName=true);
 
 	/* getPosition
 	 * returns the position of an active sample. If EMPTY o MISSING
@@ -145,33 +160,26 @@ public:
 
 	void sum(int frame, bool running);
 
-	/* setPitch
-	 * updates the pitch value and chanStart+chanEnd accordingly. */
 
 	void setPitch(float v);
 	float getPitch();
-
-	/* setStart/end
-	 * change begin/end read points in sample. */
-
-	void setBegin(int v);
-	void setEnd  (int v);
+	void setBegin(int f);
+	int getBegin();
+	void setEnd(int f);
+	int getEnd();
+	void setTrackerPreview(int f);
+	int getTrackerPreview() const;
 
 	/* save
 	 * save sample to file. */
 
-	int save(const char *path);
+	int save(const char* path);
 
 	/* hardStop
 	 * stop the channel immediately, no further checks. */
 
 	void hardStop(int frame);
 
-	/* allocEmpty
-	 * alloc an empty wave used in input recordings. */
-
-	bool allocEmpty(int frames, int samplerate, int takeId);
-
 	/* setReadActions
 	 * if enabled (v == true), recorder will read actions from this channel. If
 	 * recsStopOnChanHalt == true, stop reading actions right away. */
@@ -181,23 +189,23 @@ public:
 	void setBoost(float v);
 	float getBoost();	
 
+	void setOnEndPreviewCb(std::function<void()> f);
+
 	/* ------------------------------------------------------------------------ */
 
-	Wave  *wave;
-	int    tracker;         // chan position
-	int    begin;
-	int    end;
-	int    mode;            // mode: see const.h
-	bool   qWait;           // quantizer wait
-	bool   fadeinOn;
-	float  fadeinVol;
-	bool   fadeoutOn;
-	float  fadeoutVol;      // fadeout volume
-	int    fadeoutTracker;  // tracker fadeout, xfade only
-	float  fadeoutStep;     // fadeout decrease
-  int    fadeoutType;     // xfade or fadeout
-  int		 fadeoutEnd;      // what to do when fadeout ends
-  bool   inputMonitor;
+	Wave* wave;
+	int   tracker;         // chan position
+	int   mode;            // mode: see const.h
+	bool  qWait;           // quantizer wait
+	bool  fadeinOn;
+	float fadeinVol;
+	bool  fadeoutOn;
+	float fadeoutVol;      // fadeout volume
+	int   fadeoutTracker;  // tracker fadeout, xfade only
+	float fadeoutStep;     // fadeout decrease
+  int   fadeoutType;     // xfade or fadeout
+  int		fadeoutEnd;      // what to do when fadeout ends
+  bool  inputMonitor;
 
 	/* midi stuff */
 
