@@ -38,7 +38,6 @@
 #include "../../core/sampleChannel.h"
 #include "../../core/mixer.h"
 #include "../../core/wave.h"
-#include "../../core/clock.h"
 #include "../../utils/gui.h"
 #include "../../utils/string.h"
 #include "../elems/basics/button.h"
@@ -59,106 +58,43 @@
 #include "sampleEditor.h"
 
 
+using std::string;
 using namespace giada::m;
 using namespace giada::c;
 
 
-gdSampleEditor::gdSampleEditor(SampleChannel *ch)
+gdSampleEditor::gdSampleEditor(SampleChannel* ch)
   : gdWindow(640, 480),
     ch(ch)
 {
-  begin();
+  Fl_Group* upperBar = createUpperBar();
+  
+  waveTools = new geWaveTools(8, upperBar->y()+upperBar->h()+8, w()-16, h()-128, 
+  	ch);
+  
+  Fl_Group* bottomBar = createBottomBar(8, waveTools->y()+waveTools->h()+8, 
+  	h()-waveTools->h()-upperBar->h()-32);
 
-  /* top bar: grid and zoom tools */
+  add(upperBar);
+  add(waveTools);
+  add(bottomBar);
 
-  Fl_Group *bar = new Fl_Group(8, 8, w()-16, 20);
-  bar->begin();
-    grid    = new geChoice(bar->x(), bar->y(), 50, 20);
-    snap    = new geCheck(grid->x()+grid->w()+4, bar->y(), 12, 12);
-    sep1    = new geBox(snap->x()+snap->w()+4, bar->y(), 506, 20);
-    zoomOut = new geButton(sep1->x()+sep1->w()+4, bar->y(), 20, 20, "", zoomOutOff_xpm, zoomOutOn_xpm);
-    zoomIn  = new geButton(zoomOut->x()+zoomOut->w()+4, bar->y(), 20, 20, "", zoomInOff_xpm, zoomInOn_xpm);
-  bar->end();
-  bar->resizable(sep1);
-
-  /* waveform */
-
-  waveTools = new geWaveTools(8, bar->y()+bar->h()+8, w()-16, h()-128, ch);
-  waveTools->end();
-
-  /* other tools */
-
-  Fl_Group *row1 = new Fl_Group(8, waveTools->y()+waveTools->h()+8, w()-16, 20);
-  row1->begin();
-    volumeTool = new geVolumeTool(row1->x(), row1->y(), ch);
-    boostTool  = new geBoostTool(volumeTool->x()+volumeTool->w()+4, row1->y(), ch);
-    panTool    = new gePanTool(boostTool->x()+boostTool->w()+4, row1->y(), ch);
-  row1->end();
-  row1->resizable(0);
-
-  Fl_Group *row2 = new Fl_Group(8, row1->y()+row1->h()+8, 800, 20);
-  row2->begin();
-    pitchTool = new gePitchTool(row2->x(), row2->y(), ch);
-  row2->end();
-  row2->resizable(0);
-
-  Fl_Group *row3 = new Fl_Group(8, row2->y()+row2->h()+8, w()-16, 20);
-  row3->begin();
-    rangeTool = new geRangeTool(row3->x(), row3->y(), ch);
-    sep2      = new geBox(rangeTool->x()+rangeTool->w()+4, row3->y(), 246, 20);
-    reload    = new geButton(sep2->x()+sep2->w()+4, row3->y(), 70, 20, "Reload");
-  row3->end();
-  row3->resizable(sep2);
-
-  end();
-
-  /* grid tool setup */
-
-  grid->add("(off)");
-  grid->add("2");
-  grid->add("3");
-  grid->add("4");
-  grid->add("6");
-  grid->add("8");
-  grid->add("16");
-  grid->add("32");
-  grid->add("64");
-  if (conf::sampleEditorGridVal == 0)
-    grid->value(0);
-  else 
-    grid->value(grid->find_item(gu_itoa(conf::sampleEditorGridVal).c_str()));
-  grid->callback(cb_changeGrid, (void*)this);
-
-  snap->value(conf::sampleEditorGridOn);
-  snap->callback(cb_enableSnap, (void*)this);
-
-  /* TODO - redraw grid if != (off) */
-
-  reload->callback(cb_reload, (void*)this);
-
-  zoomOut->callback(cb_zoomOut, (void*)this);
-  zoomIn->callback(cb_zoomIn, (void*)this);
-
-  /* logical samples (aka takes) cannot be reloaded. So far. */
-
-  if (ch->wave->isLogical)
-    reload->deactivate();
-
-  gu_setFavicon(this);
-  size_range(640, 480);
   resizable(waveTools);
 
-  label(ch->wave->name.c_str());
-
+  gu_setFavicon(this);
   set_non_modal();
+  copy_label(ch->wave->getName().c_str());
 
+  size_range(720, 480);
   if (conf::sampleEditorX)
-    resize(conf::sampleEditorX, conf::sampleEditorY, conf::sampleEditorW, conf::sampleEditorH);
-
+    resize(conf::sampleEditorX, conf::sampleEditorY, conf::sampleEditorW, 
+    	conf::sampleEditorH);
+  
   show();
 }
 
 
+
 /* -------------------------------------------------------------------------- */
 
 
@@ -170,17 +106,156 @@ gdSampleEditor::~gdSampleEditor()
   conf::sampleEditorH = h();
   conf::sampleEditorGridVal = atoi(grid->text());
   conf::sampleEditorGridOn  = snap->value();
+  sampleEditor::setPreview(ch, G_PREVIEW_NONE);
 }
 
 
 /* -------------------------------------------------------------------------- */
 
 
-void gdSampleEditor::cb_reload    (Fl_Widget *w, void *p) { ((gdSampleEditor*)p)->__cb_reload(); }
-void gdSampleEditor::cb_zoomIn    (Fl_Widget *w, void *p) { ((gdSampleEditor*)p)->__cb_zoomIn(); }
-void gdSampleEditor::cb_zoomOut   (Fl_Widget *w, void *p) { ((gdSampleEditor*)p)->__cb_zoomOut(); }
-void gdSampleEditor::cb_changeGrid(Fl_Widget *w, void *p) { ((gdSampleEditor*)p)->__cb_changeGrid(); }
-void gdSampleEditor::cb_enableSnap(Fl_Widget *w, void *p) { ((gdSampleEditor*)p)->__cb_enableSnap(); }
+Fl_Group* gdSampleEditor::createUpperBar()
+{
+  Fl_Group* g = new Fl_Group(8, 8, w()-16, 20);
+  g->begin();
+    grid    = new geChoice(g->x(), g->y(), 50, 20);
+    snap    = new geCheck(grid->x()+grid->w()+4, g->y()+3, 12, 12, "Snap");
+    sep1    = new geBox(snap->x()+snap->w()+4, g->y(), 506, 20);
+    zoomOut = new geButton(sep1->x()+sep1->w()+4, g->y(), 20, 20, "", zoomOutOff_xpm, zoomOutOn_xpm);
+    zoomIn  = new geButton(zoomOut->x()+zoomOut->w()+4, g->y(), 20, 20, "", zoomInOff_xpm, zoomInOn_xpm);
+  g->end();
+  g->resizable(sep1);
+
+  grid->add("(off)");
+  grid->add("2");
+  grid->add("3");
+  grid->add("4");
+  grid->add("6");
+  grid->add("8");
+  grid->add("16");
+  grid->add("32");
+  grid->add("64");
+  if (conf::sampleEditorGridVal == 0)
+    grid->value(0);
+  else 
+    grid->value(grid->find_item(gu_toString(conf::sampleEditorGridVal).c_str()));
+  grid->callback(cb_changeGrid, (void*)this);
+
+  snap->value(conf::sampleEditorGridOn);
+  snap->callback(cb_enableSnap, (void*)this);
+
+  /* TODO - redraw grid if != (off) */
+
+  zoomOut->callback(cb_zoomOut, (void*)this);
+  zoomIn->callback(cb_zoomIn, (void*)this);
+
+  return g;
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+Fl_Group* gdSampleEditor::createOpTools(int x, int y, int h)
+{
+  Fl_Group* g = new Fl_Group(x, y, 572, h);
+  g->begin();
+  g->resizable(0);
+    volumeTool = new geVolumeTool(g->x(), g->y(), ch);
+    boostTool  = new geBoostTool(volumeTool->x()+volumeTool->w()+4, g->y(), ch);
+    panTool    = new gePanTool(boostTool->x()+boostTool->w()+4, g->y(), ch);
+   
+    pitchTool = new gePitchTool(g->x(), panTool->y()+panTool->h()+8, ch);
+
+    rangeTool = new geRangeTool(g->x(), pitchTool->y()+pitchTool->h()+8, ch);
+    reload    = new geButton(g->x()+g->w()-70, rangeTool->y(), 70, 20, "Reload");
+  g->end();
+
+  if (ch->wave->isLogical()) // Logical samples (aka takes) cannot be reloaded.
+    reload->deactivate();
+
+  reload->callback(cb_reload, (void*)this);
+
+  return g;
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+Fl_Group* gdSampleEditor::createPreviewBox(int x, int y, int h)
+{
+  Fl_Group* g = new Fl_Group(x, y, 110, h);
+  g->begin();
+    rewind = new geButton(g->x(), g->y()+(g->h()/2)-12, 25, 25, "", rewindOff_xpm, rewindOn_xpm);
+    play   = new geButton(rewind->x()+rewind->w()+4, g->y()+(g->h()/2)-12, 25, 25, "", play_xpm, pause_xpm);
+    loop   = new geCheck(play->x()+play->w()+6, g->y()+(g->h()/2)-6, 12, 12, "Loop");
+  g->end();
+
+  play->callback(cb_togglePreview, (void*)this);
+  rewind->callback(cb_rewindPreview, (void*)this);
+
+  ch->setOnEndPreviewCb([this] { 
+  	play->value(0);
+  });
+
+  return g;
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+Fl_Group* gdSampleEditor::createInfoBox(int x, int y, int h)
+{
+  Fl_Group* g = new Fl_Group(x, y, 400, h);
+  g->begin();
+    info = new geBox(g->x(), g->y(), g->w(), g->h());
+  g->end();	
+
+  info->align(FL_ALIGN_LEFT | FL_ALIGN_INSIDE | FL_ALIGN_TOP);
+  
+  updateInfo();
+
+  return g;
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+Fl_Group* gdSampleEditor::createBottomBar(int x, int y, int h)
+{
+  Fl_Group* g = new Fl_Group(8, waveTools->y()+waveTools->h()+8, w()-16, h);
+  g->begin();
+    Fl_Group* previewBox = createPreviewBox(g->x(), g->y(), g->h());
+
+    geBox* divisor1 = new geBox(previewBox->x()+previewBox->w()+8, g->y(), 1, g->h());
+    divisor1->box(FL_BORDER_BOX);
+
+    Fl_Group* opTools = createOpTools(divisor1->x()+divisor1->w()+12, g->y(), g->h());
+
+    geBox* divisor2 = new geBox(opTools->x()+opTools->w()+8, g->y(), 1, g->h());
+    divisor2->box(FL_BORDER_BOX);
+
+    createInfoBox(divisor2->x()+divisor2->w()+8, g->y(), g->h());
+
+  g->end();
+  g->resizable(0);
+
+  return g;
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void gdSampleEditor::cb_reload       (Fl_Widget* w, void* p) { ((gdSampleEditor*)p)->__cb_reload(); }
+void gdSampleEditor::cb_zoomIn       (Fl_Widget* w, void* p) { ((gdSampleEditor*)p)->__cb_zoomIn(); }
+void gdSampleEditor::cb_zoomOut      (Fl_Widget* w, void* p) { ((gdSampleEditor*)p)->__cb_zoomOut(); }
+void gdSampleEditor::cb_changeGrid   (Fl_Widget* w, void* p) { ((gdSampleEditor*)p)->__cb_changeGrid(); }
+void gdSampleEditor::cb_enableSnap   (Fl_Widget* w, void* p) { ((gdSampleEditor*)p)->__cb_enableSnap(); }
+void gdSampleEditor::cb_togglePreview(Fl_Widget* w, void* p) { ((gdSampleEditor*)p)->__cb_togglePreview(); }
+void gdSampleEditor::cb_rewindPreview(Fl_Widget* w, void* p) { ((gdSampleEditor*)p)->__cb_rewindPreview(); }
 
 
 /* -------------------------------------------------------------------------- */
@@ -195,18 +270,36 @@ void gdSampleEditor::__cb_enableSnap()
 /* -------------------------------------------------------------------------- */
 
 
+void gdSampleEditor::__cb_togglePreview()
+{
+	if (play->value())
+  	sampleEditor::setPreview(ch, G_PREVIEW_NONE);
+	else
+  	sampleEditor::setPreview(ch, loop->value() ? G_PREVIEW_LOOP : G_PREVIEW_NORMAL);
+}
+
+
+void gdSampleEditor::__cb_rewindPreview()
+{
+	sampleEditor::rewindPreview(ch);
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
 void gdSampleEditor::__cb_reload()
 {
+  /* TODO - move to glue::sampleEditor */
   if (!gdConfirmWin("Warning", "Reload sample: are you sure?"))
     return;
 
-  /* no need for glue_loadChan, there's no gui to refresh */
-
-  ch->load(ch->wave->pathfile.c_str(), conf::samplerate, conf::rsmpQuality);
+  if (glue_loadChannel(ch, ch->wave->getPath()) != G_RES_OK)
+    return;
 
   glue_setBoost(ch, G_DEFAULT_BOOST);
   glue_setPitch(ch, G_DEFAULT_PITCH);
-  glue_setPanning(ch, 1.0f);
+  glue_setPanning(ch, 0.5f);
 
   panTool->refresh();
   boostTool->refresh();
@@ -214,7 +307,7 @@ void gdSampleEditor::__cb_reload()
   waveTools->waveform->stretchToWindow();
   waveTools->updateWaveform();
 
-  sampleEditor::setBeginEndChannel(ch, 0, ch->wave->size);
+  sampleEditor::setBeginEnd(ch, 0, ch->wave->getSize());
 
   redraw();
 }
@@ -247,3 +340,19 @@ void gdSampleEditor::__cb_changeGrid()
 {
   waveTools->waveform->setGridLevel(atoi(grid->text()));
 }
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void gdSampleEditor::updateInfo()
+{
+	string bitDepth = ch->wave->getBits() != 0 ? gu_toString(ch->wave->getBits()) : "(unknown)";
+	string infoText = 
+		"File: "  + ch->wave->getPath() + "\n"
+		"Size: " + gu_toString(ch->wave->getSize()) + " frames\n"
+		"Duration: " + gu_toString(ch->wave->getDuration()) + " seconds\n"
+		"Bit depth: " + bitDepth + "\n"
+		"Frequency: " + gu_toString(ch->wave->getRate()) + " Hz\n";
+	info->copy_label(infoText.c_str());
+}
