@@ -74,7 +74,7 @@ geTabPlugins::geTabPlugins(int X, int Y, int W, int H)
 
 void geTabPlugins::updateCount()
 {
-	string scanLabel = "Scan (" + gu_itoa(pluginHost::countAvailablePlugins()) + " found)";
+	string scanLabel = "Scan (" + gu_toString(pluginHost::countAvailablePlugins()) + " found)";
 	scanButton->label(scanLabel.c_str());
 }
 
@@ -90,7 +90,7 @@ void geTabPlugins::cb_scan(Fl_Widget *w, void *p) { ((geTabPlugins*)p)->__cb_sca
 
 void geTabPlugins::cb_onScan(float progress, void *p)
 {
-	string l = "Scan in progress (" + gu_itoa((int)(progress*100)) + "%). Please wait...";
+	string l = "Scan in progress (" + gu_toString((int)(progress*100)) + "%). Please wait...";
 	((geTabPlugins *)p)->info->label(l.c_str());
 	Fl::wait();
 }
