@@ -36,7 +36,9 @@
 #include "../../../dialogs/gd_pluginList.h"
 #include "../../basics/idButton.h"
 #include "../../basics/dial.h"
+#include "../../basics/statusButton.h"
 #include "column.h"
+#include "channelStatus.h"
 #include "channelButton.h"
 #include "channel.h"
 
@@ -49,8 +51,8 @@ using namespace giada::m;
 
 geChannel::geChannel(int X, int Y, int W, int H, int type, Channel *ch)
  : Fl_Group(X, Y, W, H, nullptr),
-   ch      (ch),
-   type    (type)
+	 ch      (ch),
+	 type    (type)
 {
 }
 
@@ -72,7 +74,7 @@ void geChannel::cb_openFxWindow(Fl_Widget *v, void *p) { ((geChannel*)p)->__cb_o
 
 void geChannel::__cb_arm()
 {
-  glue_toggleArm(ch, true);
+	glue_toggleArm(ch, true);
 }
 
 
@@ -141,7 +143,7 @@ void geChannel::blink()
 	if (gu_getBlinker() > 6)
 		mainButton->setPlayMode();
 	else
-    mainButton->setDefaultMode();
+		mainButton->setDefaultMode();
 }
 
 
@@ -150,36 +152,36 @@ void geChannel::blink()
 
 void geChannel::setColorsByStatus(int playStatus, int recStatus)
 {
-  switch (playStatus) {
-    case STATUS_OFF:
-    case STATUS_EMPTY:
-  		mainButton->setDefaultMode();
-      button->imgOn  = channelPlay_xpm;
-      button->imgOff = channelStop_xpm;
-      button->redraw();
-      break;
-    case STATUS_PLAY:
-      mainButton->setPlayMode();
-      button->imgOn  = channelStop_xpm;
-      button->imgOff = channelPlay_xpm;
-      button->redraw();
-      break;
-    case STATUS_WAIT:
-      blink();
-      break;
-    case STATUS_ENDING:
-      mainButton->setEndingMode();
-      break;
-  }
+	switch (playStatus) {
+		case STATUS_OFF:
+		case STATUS_EMPTY:
+			mainButton->setDefaultMode();
+			button->imgOn  = channelPlay_xpm;
+			button->imgOff = channelStop_xpm;
+			button->redraw();
+			break;
+		case STATUS_PLAY:
+			mainButton->setPlayMode();
+			button->imgOn  = channelStop_xpm;
+			button->imgOff = channelPlay_xpm;
+			button->redraw();
+			break;
+		case STATUS_WAIT:
+			blink();
+			break;
+		case STATUS_ENDING:
+			mainButton->setEndingMode();
+			break;
+	}
 
-  switch (recStatus) {
-    case REC_WAITING:
-      blink();
-      break;
-    case REC_ENDING:
-      mainButton->setEndingMode();
-      break;
-  }
+	switch (recStatus) {
+		case REC_WAITING:
+			blink();
+			break;
+		case REC_ENDING:
+			mainButton->setEndingMode();
+			break;
+	}
 }
 
 
@@ -188,31 +190,32 @@ void geChannel::setColorsByStatus(int playStatus, int recStatus)
 
 void geChannel::packWidgets()
 {
-  /* Count visible widgets and resize mainButton according to how many widgets
-  are visible. */
+	/* Count visible widgets and resize mainButton according to how many widgets
+	are visible. */
 
-  int visibles = 0;
-  for (int i=0; i<children(); i++) {
-    child(i)->size(20, 20);  // also normalize widths
-    if (child(i)->visible())
-      visibles++;
-  }
-  mainButton->size(w() - ((visibles - 1) * (24)), 20);  // -1: exclude itself
+	int visibles = 0;
+	for (int i=0; i<children(); i++) {
+		child(i)->size(MIN_ELEM_W, child(i)->h());  // also normalize widths
+		if (child(i)->visible())
+			visibles++;
+	}
+	mainButton->size(w() - ((visibles - 1) * (MIN_ELEM_W + G_GUI_INNER_MARGIN)),   // -1: exclude itself
+		mainButton->h());
 
-  /* Reposition everything else */
+	/* Reposition everything else */
 
-  for (int i=1, p=0; i<children(); i++) {
-    if (!child(i)->visible())
-      continue;
-    for (int k=i-1; k>=0; k--) // Get the first visible item prior to i
-      if (child(k)->visible()) {
-        p = k;
-        break;
-      }
-    child(i)->position(child(p)->x() + child(p)->w() + 4, y());
-  }
+	for (int i=1, p=0; i<children(); i++) {
+		if (!child(i)->visible())
+			continue;
+		for (int k=i-1; k>=0; k--) // Get the first visible item prior to i
+			if (child(k)->visible()) {
+				p = k;
+				break;
+			}
+		child(i)->position(child(p)->x() + child(p)->w() + G_GUI_INNER_MARGIN, child(i)->y());
+	}
 
-  init_sizes(); // Resets the internal array of widget sizes and positions
+	init_sizes(); // Resets the internal array of widget sizes and positions
 }
 
 
@@ -239,3 +242,33 @@ int geChannel::handleKey(int e, int key)
 
 	return ret;
 }
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void geChannel::changeSize(int H)
+{
+	size(w(), H);
+	
+	int Y = y() + (H / 2 - (G_GUI_UNIT / 2));
+
+	button->resize(x(), Y, w(), G_GUI_UNIT);
+	arm->resize(x(), Y, w(), G_GUI_UNIT);   
+	mainButton->resize(x(), y(), w(), H);
+	mute->resize(x(), Y, w(), G_GUI_UNIT);
+	solo->resize(x(), Y, w(), G_GUI_UNIT);
+	vol->resize(x(), Y, w(), G_GUI_UNIT);
+#ifdef WITH_VST
+	fx->resize(x(), Y, w(), G_GUI_UNIT);
+#endif
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+int geChannel::getSize()
+{
+	return h();
+}
