@@ -43,64 +43,55 @@ class geColumn : public Fl_Group
 {
 private:
 
-	static void cb_addChannel  (Fl_Widget *v, void *p);
+	static void cb_addChannel  (Fl_Widget* v, void* p);
 	inline void __cb_addChannel();
 
 	int openTypeMenu();
 
-	geButton    *addChannelBtn;
-	geResizerBar *resizer;
-	geKeyboard  *parent;
+	geButton*     m_addChannelBtn;
+	geResizerBar* m_resizer;
+	geKeyboard*   m_parent;
 
-	int index;
+	int m_index;
 
 public:
 
-	geColumn(int x, int y, int w, int h, int index, geKeyboard *parent);
+	geColumn(int x, int y, int w, int h, int index, geKeyboard* parent);
 	~geColumn();
 
 	/* addChannel
-	 * add a new channel in this column and set the internal pointer
-	 * to channel to 'ch'. */
+	Adds a new channel in this column and set the internal pointer to channel 
+	to 'ch'. */
 
-	geChannel *addChannel(Channel *ch);
+	geChannel* addChannel(Channel* ch, int size);
 
-	/* handle */
-
-	int handle(int e);
-
-  /* resize
-   * custom resize behavior. */
-
-  void resize(int x, int y, int w, int h);
-
-	/* deleteChannel
-	 * remove the channel 'gch' from this column. */
-
-	void deleteChannel(geChannel *gch);
-
-	/* refreshChannels
-	 * update channels' graphical statues. Called on each GUI cycle. */
-
-	void refreshChannels();
-
-  /* getChannel */
-
-  Channel *getChannel(int i);
+	int handle(int e) override;
+	void draw() override;
+  void resize(int x, int y, int w, int h) override;
 
 	/* clear
-	 * remove all channels from the column. If full==true, delete also the
-	 * "add new channel" button. This method ovverrides the inherited one
-	 * from Fl_Group. */
+	Removes all channels from the column. If full==true, delete also the "add new 
+	channel" button. */
 
 	void clear(bool full=false);
 
-	void draw();
+	/* deleteChannel
+	Removes the channel 'gch' from this column. */
 
-	inline int  getIndex()      { return index; }
-	inline void setIndex(int i) { index = i; }
-	inline bool isEmpty()       { return children() == 1; }
-  inline int  countChannels() { return children(); }
+	void deleteChannel(geChannel* gch);
+
+	void repositionChannels();
+
+	/* refreshChannels
+	Updates channels' graphical statues. Called on each GUI cycle. */
+
+	void refreshChannels();
+
+	Channel* getChannel(int i);
+	int getIndex();
+	void setIndex(int i);
+	bool isEmpty();   
+  int countChannels();
 };
 
 
