@@ -48,13 +48,18 @@ namespace
 {
 enum class Menu
 {
-  CUT = 0,
-  TRIM,
-  SILENCE,
-  FADE_IN,
-  FADE_OUT,
-  SMOOTH_EDGES,
-  SET_START_END
+	CUT = 0,
+	COPY,
+	PASTE,
+	TRIM,
+	SILENCE,
+	REVERSE,
+	NORMALIZE,
+	FADE_IN,
+	FADE_OUT,
+	SMOOTH_EDGES,
+	SET_BEGIN_END,
+	TO_NEW_CHANNEL
 };
 
 
@@ -63,35 +68,50 @@ enum class Menu
 
 void menuCallback(Fl_Widget* w, void* v)
 {
-  geWaveTools* wavetools = static_cast<geWaveTools*>(w);
-  Menu selectedItem = (Menu) (intptr_t) v;
+	geWaveTools* wavetools = static_cast<geWaveTools*>(w);
+	Menu selectedItem = (Menu) (intptr_t) v;
 
-  int a = wavetools->waveform->getSelectionA();
-  int b = wavetools->waveform->getSelectionB();
+	int a = wavetools->waveform->getSelectionA();
+	int b = wavetools->waveform->getSelectionB();
 
-  switch (selectedItem) {
-  	case Menu::CUT:
-      c::sampleEditor::cut(wavetools->ch, a, b);
-  		break;
-  	case Menu::TRIM:
-      c::sampleEditor::trim(wavetools->ch, a, b);
-  		break;
-  	case Menu::SILENCE:
-  		c::sampleEditor::silence(wavetools->ch, a, b);
-  		break;	
-  	case Menu::FADE_IN:
-  		c::sampleEditor::fade(wavetools->ch, a, b, 0);
-  		break;
-  	case Menu::FADE_OUT:
-  		c::sampleEditor::fade(wavetools->ch, a, b, 1);
-  		break;
-  	case Menu::SMOOTH_EDGES:
-  		c::sampleEditor::smoothEdges(wavetools->ch, a, b);
-  		break;
-  	case Menu::SET_START_END:
-  		c::sampleEditor::setStartEnd(wavetools->ch, a, b);
-  		break;
-  }
+	switch (selectedItem) {
+		case Menu::CUT:
+			c::sampleEditor::cut(wavetools->ch, a, b);
+			break;		
+		case Menu::COPY:
+			c::sampleEditor::copy(wavetools->ch, a, b);
+			break;		
+		case Menu::PASTE:
+			c::sampleEditor::paste(wavetools->ch, a);
+			break;
+		case Menu::TRIM:
+			c::sampleEditor::trim(wavetools->ch, a, b);
+			break;
+		case Menu::SILENCE:
+			c::sampleEditor::silence(wavetools->ch, a, b);
+			break;	  
+		case Menu::REVERSE:
+			c::sampleEditor::reverse(wavetools->ch, a, b);
+			break;			
+		case Menu::NORMALIZE:
+			c::sampleEditor::normalizeHard(wavetools->ch, a, b);
+			break;	
+		case Menu::FADE_IN:
+			c::sampleEditor::fade(wavetools->ch, a, b, m::wfx::FADE_IN);
+			break;
+		case Menu::FADE_OUT:
+			c::sampleEditor::fade(wavetools->ch, a, b, m::wfx::FADE_OUT);
+			break;
+		case Menu::SMOOTH_EDGES:
+			c::sampleEditor::smoothEdges(wavetools->ch, a, b);
+			break;
+		case Menu::SET_BEGIN_END:
+			c::sampleEditor::setBeginEnd(wavetools->ch, a, b);
+			break;		
+		case Menu::TO_NEW_CHANNEL:
+			c::sampleEditor::toNewChannel(wavetools->ch, a, b);
+			break;
+	}
 }
 }; // {anonymous}
 
@@ -101,7 +121,7 @@ void menuCallback(Fl_Widget* w, void* v)
 
 geWaveTools::geWaveTools(int x, int y, int w, int h, SampleChannel *ch, const char *l)
 	: Fl_Scroll(x, y, w, h, l),
-	  ch       (ch)
+		ch       (ch)
 {
 	type(Fl_Scroll::HORIZONTAL_ALWAYS);
 	hscrollbar.color(G_COLOR_GREY_2);
@@ -128,7 +148,7 @@ void geWaveTools::updateWaveform()
 
 void geWaveTools::redrawWaveformAsync()
 {
-	if (ch->status & (STATUS_PLAY | STATUS_ENDING))
+	if (ch->isPreview())
 		waveform->redraw();
 }
 
@@ -161,23 +181,22 @@ void geWaveTools::resize(int x, int y, int w, int h)
 
 int geWaveTools::handle(int e)
 {
-	int ret = Fl_Group::handle(e);
 	switch (e) {
 		case FL_MOUSEWHEEL: {
 			waveform->setZoom(Fl::event_dy());
 			redraw();
-			ret = 1;
-			break;
+			return 1;
 		}
 		case FL_PUSH: {
 			if (Fl::event_button3()) {  // right button
 				openMenu();
-				ret = 1;
+				return 1;
 			}
-			break;
+			Fl::focus(waveform);
 		}
+		default:
+			return Fl_Group::handle(e);
 	}
-	return ret;
 }
 
 
@@ -186,25 +205,40 @@ int geWaveTools::handle(int e)
 
 void geWaveTools::openMenu()
 {
-	if (!waveform->isSelected())
-		return;
-
 	Fl_Menu_Item menu[] = {
-		{"Cut",                0, menuCallback, (void*) Menu::CUT},
-    {"Trim",               0, menuCallback, (void*) Menu::TRIM},
-    {"Silence",            0, menuCallback, (void*) Menu::SILENCE},
-    {"Fade in",            0, menuCallback, (void*) Menu::FADE_IN},
-    {"Fade out",           0, menuCallback, (void*) Menu::FADE_OUT},
-    {"Smooth edges",       0, menuCallback, (void*) Menu::SMOOTH_EDGES},
-    {"Set start/end here", 0, menuCallback, (void*) Menu::SET_START_END},
-    {0}
+		{"Cut",                 0, menuCallback, (void*) Menu::CUT},
+		{"Copy",                0, menuCallback, (void*) Menu::COPY},
+		{"Paste",               0, menuCallback, (void*) Menu::PASTE},
+		{"Trim",                0, menuCallback, (void*) Menu::TRIM},
+		{"Silence",             0, menuCallback, (void*) Menu::SILENCE},
+		{"Reverse",             0, menuCallback, (void*) Menu::REVERSE},
+		{"Normalize",           0, menuCallback, (void*) Menu::NORMALIZE},
+		{"Fade in",             0, menuCallback, (void*) Menu::FADE_IN},
+		{"Fade out",            0, menuCallback, (void*) Menu::FADE_OUT},
+		{"Smooth edges",        0, menuCallback, (void*) Menu::SMOOTH_EDGES},
+		{"Set begin/end here",  0, menuCallback, (void*) Menu::SET_BEGIN_END},
+		{"Copy to new channel", 0, menuCallback, (void*) Menu::TO_NEW_CHANNEL},
+		{0}
 	};
 
-  if (ch->status == STATUS_PLAY) {
-    menu[(int)Menu::CUT].deactivate();
-    menu[(int)Menu::TRIM].deactivate();
-  }
+	if (ch->status == STATUS_PLAY) {
+		menu[(int)Menu::CUT].deactivate();
+		menu[(int)Menu::TRIM].deactivate();
+	}
 
+	if (!waveform->isSelected()) {
+		menu[(int)Menu::CUT].deactivate();
+		menu[(int)Menu::COPY].deactivate();		
+		menu[(int)Menu::TRIM].deactivate();		
+		menu[(int)Menu::SILENCE].deactivate();		
+		menu[(int)Menu::REVERSE].deactivate();		
+		menu[(int)Menu::NORMALIZE].deactivate();		
+		menu[(int)Menu::FADE_IN].deactivate();		
+		menu[(int)Menu::FADE_OUT].deactivate();		
+		menu[(int)Menu::SMOOTH_EDGES].deactivate();		
+		menu[(int)Menu::SET_BEGIN_END].deactivate();		
+		menu[(int)Menu::TO_NEW_CHANNEL].deactivate();		
+	}
 
 	Fl_Menu_Button *b = new Fl_Menu_Button(0, 0, 100, 50);
 	b->box(G_CUSTOM_BORDER_BOX);
@@ -213,7 +247,7 @@ void geWaveTools::openMenu()
 	b->color(G_COLOR_GREY_2);
 
 	const Fl_Menu_Item *m = menu->popup(Fl::event_x(), Fl::event_y(), 0, 0, b);
-  if (m)
-    m->do_callback(this, m->user_data());
-  return;
+	if (m)
+		m->do_callback(this, m->user_data());
+	return;
 }
